@@ -1,6 +1,6 @@
 package Net::CLI::Interact::ActionSet;
 {
-  $Net::CLI::Interact::ActionSet::VERSION = '2.131260';
+  $Net::CLI::Interact::ActionSet::VERSION = '2.141520';
 }
 
 use Moo;
@@ -157,7 +157,7 @@ sub _marshall_responses {
         next unless $match->type eq 'match';
 
         # remove echoed command from the beginning
-        my $cmd = quotemeta( $send->value );
+        my $cmd = quotemeta( sprintf $send->value, @{ $send->params } );
         (my $output = $match->response_stash) =~ s/^${cmd}[\t ]*(?:\r\n|\r|\n)?//s;
         $send->response($output);
     }
@@ -177,7 +177,7 @@ Net::CLI::Interact::ActionSet - Conversation of Send and Match Actions
 
 =head1 VERSION
 
-version 2.131260
+version 2.141520
 
 =head1 DESCRIPTION
 
@@ -293,7 +293,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Oliver Gorwits.
+This software is copyright (c) 2014 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
