@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Transport::Wrapper::Net_Telnet;
 {
-  $Net::CLI::Interact::Transport::Wrapper::Net_Telnet::VERSION = '2.131260';
+  $Net::CLI::Interact::Transport::Wrapper::Net_Telnet::VERSION = '2.141520';
 }
 
 use Moo;
@@ -32,7 +32,7 @@ sub buffer {
 
 sub pump {
     my $self = shift;
-    my $content = $self->wrapper->get;
+    my $content = $self->wrapper->get(Timeout => $self->timeout);
     $self->_buffer($self->_buffer . $content) if defined $content;
 }
 
